s/@aacute;/á/g
s/@Aacute;/Á/g
s/@eacute;/é/g
s/@Eacute;/É/g
s/@iacute;/í/g
s/@Iacute;/Í/g
s/@ntilde;/ñ/g
s/@Ntilde;/Ñ/g
s/@oacute;/ó/g
s/@Oacute;/Ó/g
s/@uacute;/ú/g
s/@Uacute;/Ú/g
s/@uuml;/ü/g
s/@Uuml;/Ü/g
